﻿// *************************************************************************** 
// Project: Client Centric Tutorial
// Copyright (c) DotNetNuclear LLC.
// http://www.dotnetnuclear.com
//
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND, 
// EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED 
// WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A PARTICULAR PURPOSE.
// *************************************************************************** 
using System;
using System.Collections.Generic;
using DotNetNuclear.Modules.ClientCentric.Entities;
using DotNetNuke.Common.Utilities;
using DotNetNuke.Data;

namespace DotNetNuclear.Modules.ClientCentric.Components
{
    public class ItemRepository : IItemRepository
    {
        public void ClearCache(int moduleid)        
        {
            using (IDataContext ctx = DataContext.Instance())
            {
                var rep = ctx.GetRepository<Item>();
                try
                {
                    // Setup fictitous item to delete (just to clear the scope cache)
                    var t = new Item { ItemId = -1, ModuleId = moduleid };
                    DeleteItem(t);
                }
                catch { } // ignore
            }
        }

        public int CreateItem(IItemModel t)
        {
            using (IDataContext ctx = DataContext.Instance())
            {
                var rep = ctx.GetRepository<Item>();
                rep.Insert((Item)t);
                return t.ItemId;
            }
        }

        public void DeleteItem(int itemId, int moduleId)
        {
            var t = GetItem(itemId, moduleId);
            DeleteItem(t);
        }

        public void DeleteItem(IItemModel t)
        {
            using (IDataContext ctx = DataContext.Instance())
            {
                var rep = ctx.GetRepository<Item>();
                rep.Delete((Item)t);
            }
        }

        public IEnumerable<IItemModel> GetItems(int moduleId)
        {
            IEnumerable<Item> t;
            using (IDataContext ctx = DataContext.Instance())
            {
                var rep = ctx.GetRepository<Item>();
                t = rep.Get(moduleId);
            }
            return t;
        }

        public IItemModel GetItem(int itemId, int moduleId)
        {
            Item t;
            using (IDataContext ctx = DataContext.Instance())
            {
                var rep = ctx.GetRepository<Item>();
                t = rep.GetById(itemId, moduleId);
            }
            return t;
        }

        public IEnumerable<IItemModel> GetItemByName(int moduleId, string itemname)
        {
            IEnumerable<Item> t;
            using (IDataContext ctx = DataContext.Instance())
            {
                var rep = ctx.GetRepository<Item>();
                t = rep.Find("WHERE ModuleId = @0 AND ItemName LIKE @1", moduleId, itemname);
            }
            return t;
        }

        public void UpdateItem(IItemModel t)
        {
            using (IDataContext ctx = DataContext.Instance())
            {
                var rep = ctx.GetRepository<Item>();
                rep.Update((Item)t);
            }
        }

    }
}
