﻿
function ItemViewModel(moduleid, moduleName, editPanelId, addPanelId, editable) {
    //Make the self as 'this' reference
    var self = this;

    var dnItemSf = $.ServicesFramework(moduleid);

    //Declare observable which will be bind with UI 
    self.ItemId = ko.observable(0);
    self.AssignedUserId = ko.observable(0);
    self.ItemName = ko.observable("");
    self.ItemDescription = ko.observable("");
    self.CreatedByUserId = ko.observable(0);
    self.Status = ko.observable("");
    self.Editable = ko.observable(editable);

    // Simple object representing the current edited Item
    var Item = {
        ItemId: self.ItemId,
        AssignedUserId: self.AssignedUserId,
        ItemName: self.ItemName,
        ItemDescription: self.ItemDescription,
        CreatedByUserId: self.CreatedByUserId
    };

    self.Item = ko.observable();
    self.Items = ko.observableArray(); // Contains the list of items

    // Initialize the view-model
    $.ajax({
        type: "GET",
        url: dnItemSf.getServiceRoot(moduleName) + "item/list",
        beforeSend: dnItemSf.setModuleHeaders,
        dataType: "json",
        success: function (data) {
            self.Items(data); //Put the response in ObservableArray
        }
    });

    // Calculate number of items
    self.ItemCount = ko.computed(function () {
        return self.Items().length;
    });

    //Add New Item
    self.create = function () {
        if (Item.ItemName() != "" && Item.ItemDescription() != "") {
            $.ajax({
                type: "POST",
                url: dnItemSf.getServiceRoot(moduleName) + "item/new",
                beforeSend: dnItemSf.setModuleHeaders,
                data: ko.toJSON(Item),
                dataType: "json",
                processData: false,
                contentType: "application/json; charset=utf-8",
                success: function (data) {
                    var id = parseInt(data);
                    if (id > 0) {
                        self.getitem(id);
                        self.Items.push(self.Item());
                        self.reset();
                    }
                }
            }).fail(function (xhr, textStatus, err) {
                self.Status(err);
            });
        }
        else {
            alert('Please enter a name and description');
        }

    }
    // Delete item details
    self.delete = function (Item) {
        if (confirm('Are you sure to delete "' + Item.ItemName + '"?')) {
            var id = Item.ItemId;
            $.ajax({
                type: "POST",
                url: dnItemSf.getServiceRoot(moduleName) + "item/delete",
                beforeSend: dnItemSf.setModuleHeaders,
                cache: false,
                data: ko.toJSON(Item),
                processData: false,
                contentType: "application/json; charset=utf-8",
                success: function (data) {
                    self.Items.remove(Item);
                }
            }).fail(
            function (xhr, textStatus, err) {
                self.Status(err);
            });
        }
    }

    // Edit item details
    self.addNew = function() {
        $("#" + addPanelId).dialog({ modal: true, width: 450 });
    }

    // Edit item details
    self.edit = function (Item) {
        self.Item(Item);
        $("#" + editPanelId).dialog({ modal: true, width: 450 });
    }

    // Update product details
    self.update = function () {
        var fullItem = self.Item();

        $.ajax({
            type: "POST",
            cache: false,
            url: dnItemSf.getServiceRoot(moduleName) + "item/edit",
            beforeSend: dnItemSf.setModuleHeaders,
            cache: false,
            data: ko.toJSON(fullItem),
            processData: false,
            contentType: "application/json; charset=utf-8",
            success: function (data) {
                if (data == 'True') {
                    // Refresh the observable array to update the change
                    self.refreshItemList();
                    self.cancel();
                } else {
                    alert("An update error occurred: " + data);
                }
            }
        }).fail(
        function (xhr, textStatus, err) {
            self.Status(err);
        });
    }

    // Get single item details
    self.getitem = function (id) {
        $.ajax({
            type: "POST",
            url: dnItemSf.getServiceRoot(moduleName) + "item/byid",
            beforeSend: dnItemSf.setModuleHeaders,
            cache: false,
            data: ko.toJSON({ "ItemId": id }),
            async: false,
            processData: false,
            contentType: "application/json; charset=utf-8",
            success: function (data) {
                self.Item(data);
            }
        }).fail(
        function (xhr, textStatus, err) {
            self.Status(err);
        });
    }

    // Reset item details
    self.reset = function () {
        $("#" + addPanelId).dialog('close');
        self.ItemId(0);
        self.AssignedUserId(0);
        self.ItemName("");
        self.ItemDescription("");
    }

    self.refreshItemList = function () {
        var data = self.Items().slice(0);
        self.Items([]);
        self.Items(data);
    };

    // Cancel item details
    self.cancel = function () {
        $("#" + editPanelId).dialog('close');
        self.Item(null);
    }
}